@@ -1,14 +1,14 @@
 ##########################################
 ##########################################
-##					##
-##	WaitBoxFixed - a reusable Tk-widget	##
-##		  Wait Dialog		##
-##					##
-##	Version 1.3			##
-##					##
-##	Brent B. Powers	(B2Pi)		##
-##	Powers@B2Pi.com			##
-##					##
+##                                      ##
+##  WaitBoxFixed - a reusable Tk-widget ##
+##                 Wait Dialog          ##
+##                                      ##
+##  Version 1.6                         ##
+##                                      ##
+##  Brent B. Powers	(B2Pi)              ##
+##  Powers@B2Pi.com                     ##
+##                                      ##
 ##########################################
 ##########################################
 
@@ -26,6 +26,7 @@
 ##	   <benh@med.ge.com>, some other stuff
 ## Ver 1.4 Cavac: Added some fixes
 ## Ver 1.5 Cavac: Added some fixes
+## Ver 1.6 Cavac, ASB: fixes and cleanup of POD
 ##
 ###############################################################################
 ###############################################################################
@@ -39,15 +40,13 @@ use Tk::Toplevel;
 
 Tk::Widget->Construct('WaitBoxFixed');
 
-$Tk::WaitBoxFixed::VERSION = '1.5';
+$Tk::WaitBoxFixed::VERSION = '1.6';
 
 ### A couple of convenience variables
 my(@wd_fullpack) = (-expand => 1, -fill => 'both');
 my(@wd_packtop) = (-side => 'top');
 my(@wd_packleft) = (-side => 'left');
 
-1;
-
 sub Populate {
     ### Wait box constructor.  Uses new inherited from base class
     my($cw, $wdtop, $fm, $bitmap, $txt1, $uframe, $txt2);
@@ -112,6 +111,8 @@ sub Populate {
 		     -txt2	=> ['PASSIVE',undef,undef,undef],
 		     -resizeable => ['PASSIVE',undef,undef,1],
 		     -takefocus => ['SELF', undef, undef, 1]);
+
+    return;
 }
 
 sub Version {return $Tk::WaitBoxFixed::VERSION;}
@@ -174,8 +175,12 @@ sub unShow {
     $wd->withdraw;
     $wd->parent->update;
     $wd->{Shown} = 0;
+
+    return;
 }
 
+1;
+
 __END__
 
 =head1 NAME
@@ -186,10 +191,6 @@ Tk::WaitBoxFixed - An Object Oriented Wait Dialog for Perl/Tk, of the Please Wai
 
 A WaitBoxFixed consists of a number of subwidgets:
 
-=over 4
-
-=item
-
 =head2 bitmap
 
 A bitmap (configurable via the I<-bitmap> command, the default is an hourglass) on the left side of the WaitBoxFixed
@@ -210,27 +211,20 @@ A frame displayed, if required, between the label and the secondary label.  For
 
 If a cancelroutine (configured via the I<-cancelroutine> command) is defined, a frame will be packed below the labels and bitmap, with a single button.  The text of the button will be 'Cancel' (configurable via the I<-canceltext> command), and the button will call the supplied subroutine when pressed.
 
-=back
-
 =head1 SYNOPSIS
 
-=over 4
+=head2 Usage Description
 
-=item Usage Description
-
-=item
-
-=head2 Basic Usage
+=head3 Basic Usage
 
 To use, create your WaitDialog objects during initialization, or at least before a Show.  When you wish to display the WaitDialog object, invoke the 'Show' method on the WaitDialog object; when you wish to cease displaying the WaitDialog object, invoke the 'unShow' method on the object.
 
-=head2 Configuration
+=head3 Configuration
 
 Configuration may be done at creation or via the configure method.  
 
-=head2 Example Code
+=head3 Example Code
 
-=item
     #!/usr/local/bin/perl -w 
 
     ## Dependent on Graham Barr's Tk::ProgressBar
@@ -290,8 +284,6 @@ Configuration may be done at creation or via the configure method.
     sleep(2);
     $wd->unShow;
 
-=back
-
 
 =head1 Advertised Subwidgets
 
@@ -301,7 +293,7 @@ Configuration may be done at creation or via the configure method.
 
 uframe is a frame created between the two messages.  It may be used for anything the user has in mind... including exciting cycle wasting displays of sand dropping through an hour glass, Zippy riding either a Gnu or a bronc, et cetera.
 
-Assuming that the WaitBoxFixed is referenced by $w, the uframe may be addressed as $w->subwidget{uframe}.  Having gotten the address, you can do anything (I think) you would like with it
+Assuming that the WaitBoxFixed is referenced by C<$w>, the uframe may be addressed as C<$w-E<gt>subwidget{uframe}>.  Having gotten the address, you can do anything (I think) you would like with it
 
 =back
 
@@ -311,7 +303,7 @@ Assuming that the WaitBoxFixed is referenced by $w, the uframe may be addressed
 
 =item -takefocus
 
-Specifying -takeFocus = 0 will prevent the WaitBoxFixed widget from taking focus. Default is to take focus and do an application grab. I'm not sure why, but someone told me it was necessary.
+Specifying C<-takeFocus =E<gt> 0> will prevent the WaitBoxFixed widget from taking focus. Default is to take focus and do an application grab. I'm not sure why, but someone told me it was necessary.
 
 =back
 
@@ -327,5 +319,8 @@ B<Rene Schickbauer> rene.schickbauer@magnapowertrain.com
 
 (C) 2013, Rene Schickbauer, same license
 
+B<Alexander Becker>, asb@cpan.org
+
+(C) 2016 Alexander Becker, same license
 
 =cut
